/***************************************************************************
 *   Copyright (C) 2008 by Kai Dombrowe <just89@gmx.de>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/
#ifndef FRAME_H
#define FRAME_H

/// Qt
#include <QtGui/QGraphicsWidget>
#include <QGraphicsSceneResizeEvent>
/// KDE
#include <Plasma/FrameSvg>
#include <Plasma/Theme>

#include "yasp_export.h"

namespace Yasp {


class YASP_EXPORT Frame : public QGraphicsWidget
{
    Q_OBJECT


public:
    enum Shadow {
        Plain = 1,
        Raised = 2,
        Sunken = 3
    };

    Frame(QGraphicsWidget *parent = 0);
    ~Frame();


public slots:
    void setText(const QString &newText);
    void setColor(const QColor &newColor);
    void setFrameShadow(Shadow newShadow);
    void setFont(const QFont& newFont);
    void updateAppearance(const QColor& newColor, const QFont& newFont, Shadow newShadow);

    qreal minHeight();
    qreal minWidth();


private:
    Plasma::FrameSvg *_svg;
    QString _text;
    QColor _color;
    Shadow _shadow;
    QFont _font;


private slots:
    void syncBorders();


protected:
    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
    void resizeEvent(QGraphicsSceneResizeEvent *event);


};


} // namespace Yasp


#endif
