/***************************************************************************
 *   Copyright (C) 2009 by Kai Dombrowe <just89@gmx.de>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/
#ifndef LABEL_H
#define LABEL_H


/// Qt
#include <QGraphicsWidget>

/// KDE
#include <KIcon>

/// own
#include "index.h"
#include "yasp_export.h"



namespace Yasp {


class Index;
class YASP_EXPORT Label : public QGraphicsWidget
{
    Q_OBJECT


public:
    Label(const KIcon& icon = KIcon(), QGraphicsWidget *parent = 0);
    ~Label();

enum State {
    Active = 0,
    Inactive = 1
};

public slots:
    void setText(const QString &newText);
    void setColor(const QColor& newColor);
    void setFont(const QFont& newFont);
    void setState(const State& newState);
    void setIcon(const KIcon& newIcon);
    void setAlignment(const Qt::Alignment& newAlignment);
    void setIndex(const Index& newIndex);

    void updateAppearance(const QColor& newColor, const QFont& newFont);

    QSizeF minSize();

    QString text();
    State state();
    Qt::Alignment alignment();
    QFont font();
    QColor color();
    Index index();


private:
    QString _text;
    QFont _font;
    QColor _color;
    KIcon _icon;
    int _row;
    int _column;
    State _state;
    Qt::Alignment _alignment;
    Index _index;


protected:
    void paint(QPainter* paint, const QStyleOptionGraphicsItem*, QWidget*);
    void mousePressEvent(QGraphicsSceneMouseEvent *event);
    void checkGeometry();


signals:
    void stateChanged(Yasp::Label::State newState);
    void geometryChanged();
    void heightChanged();

};


} // namespace Yasp


#endif
