/***************************************************************************
 *   Copyright (C) 2009 by Kai Dombrowe <just89@gmx.de>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/
#ifndef PLUGIN_H
#define PLUGIN_H


/// Qt
#include <QObject>
#include <QVariantList>

/// KDE
#include <KIcon>
#include <Plasma/Applet>
#include <kdemacros.h>
#include <KPluginInfo>

/// own
#include "yasp_export.h"


namespace Yasp {

class Widget;
class YASP_EXPORT Plugin : public QObject
{
    Q_OBJECT


    public:
        /**
        * @param args args for Yasp::Widget.
        * @param name pluginName, used to save the config.
        */
        Plugin(QObject *parent, const QVariantList &args, const QString& name);
        ~Plugin();

        QString pluginName() const;
        QString icon() const;
        /**
        * @return the widget.
        */
        Yasp::Widget *widget();
        /**
        * @return the Plasma::Applet.
        */
        Plasma::Applet *applet() const;
        bool isLoaded() const;
        KPluginInfo pluginInfo() const;
        
        
    public slots:
        void unloadPlugin();
        
        
    private:
        QString m_pluginName;
        QString m_icon;
        Widget *m_widget;
        Plasma::Applet *m_applet;
        bool m_loaded;
        KPluginInfo m_pluginInfo;
        
        
    protected slots:
        void setPluginName(const QString &newName);
        void setIcon(const QString &newIcon);
        void setWidget(Yasp::Widget *newWidget);
        void setLoaded(const bool &loaded);
        void setPluginInfo(const KPluginInfo &newInfo);
        virtual void load(){}
        virtual void unload(){}
        
        
};


} // namespace Yasp


#endif
