/***************************************************************************
 *   Copyright (C) 2008 by Kai Dombrowe <just89@gmx.de>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef WIDGET_HEADER
#define WIDGET_HEADER


#include "layout.h"
#include "yasp_export.h"
#include "frame.h"

/// Qt
#include <QGraphicsGridLayout>
#include <QStandardItemModel>

/// KDE
#include <Plasma/DataEngine>
#include <Plasma/Applet>

namespace Ui {
    class Misc;
    class Appearance;  
};

namespace Yasp
{


class YASP_EXPORT Widget : public QGraphicsWidget
{
    Q_OBJECT


public:
enum Mode {
    Normal = 0,
    Main = 1
};

    Widget(Plasma::Applet *parent, const QVariantList &args, const QString &name);
    ~Widget();
    void init();
    QSizeF minSize();
    Widget::Mode mode();
    void setMode(Mode newMode);
    void setupDefaultConfig(KConfigDialog *p_parent);
    void setInterval(const uint& newInterval);


private:
    Yasp::Layout *m_layout;
    Plasma::DataEngine *m_engine;
    Frame *m_title;
    uint m_interval;
    QColor m_titleColor;
    QFont m_titleFont;
    QColor m_textColor;
    QFont m_textFont;
    Plasma::Applet::BackgroundHint m_backgroundHint;
    int m_maxSize;
    Yasp::Frame::Shadow m_shadow;

    Ui::Misc *ui_misc;
    Ui::Appearance *ui_appearance;

    QStandardItemModel model;
    QStringList sources;

    Mode m_mode;
    Plasma::Applet *m_applet;
    QStringList m_dObjects;
    QString m_dataEngine;


private slots:
    virtual void dataUpdated(const QString&, const Plasma::DataEngine::Data&){};
    virtual void saveConfig();
    virtual void createConfigurationInterface(KConfigDialog *p_parent);
    virtual void setupCustomConfig( KConfigDialog*){};

    void checkGeometry();


protected slots:
    Yasp::Layout* layout();
    Plasma::DataEngine* engine();

    void addLabel(const QString& text, const QString& name, const int& row,
    const int& col, const int& rows = 1, const int& cols = 1, const QString& icon = QString());
    void setTitle(const QString& text);
    QString resizeString(QString str);

    uint interval();

    void setMaximumWordLenght(const int& newLenght);
    int maximumWordLenght();

    void connectSource(const QString& source);
    void reconnect();

    void updateAppearance();
    void updateSources();

    KConfigGroup saveDefaultConfig();
    KConfigGroup loadDefaultConfig();

    KConfigGroup config();

    QStandardItemModel* miscModel();
    void setCustomDataEngine(const QString& customDataEngine);


signals:
    void geometryChecked();


};


}; /// namespace Yasp


#endif
